=========
gee_pheno
=========


.. image:: https://img.shields.io/pypi/v/gee_pheno.svg
   :target: https://pypi.python.org/pypi/gee_pheno

.. image:: https://img.shields.io/travis/francbartoli/gee_pheno.svg
   :target: https://travis-ci.org/francbartoli/gee_pheno

.. image:: https://readthedocs.org/projects/gee-pheno/badge/?version=latest
   :target: https://gee-pheno.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status


.. image:: https://pyup.io/repos/github/francbartoli/gee_pheno/shield.svg
   :target: https://pyup.io/repos/github/francbartoli/gee_pheno/
   :alt: Updates



GEE phenology


* Free software: MIT license
* Documentation: https://gee-pheno.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
